tlslite.utils.xmltools

Package tlslite :: Package utils :: Module xmltools |
[show private | hide private]
[frames | no frames]

## Module tlslite.utils.xmltools

Helper functions for XML.

This module has misc. helper functions for working with XML DOM nodes.

Function Summary
| `checkName(element, name)`
| `checkNoMoreAttributes(element)`
| `escape(s)`
| `getAttribute(element, attrName, regEx)`
| `getChild(element, index, name)`
| `getChildIter(element, index)`
| `getChildOrNone(element, index)`
| `getLastChild(element, index, name)`
| `getReqAttribute(element, attrName, regEx)`
| `getText(element, regEx)`
| `indent(s, steps, ch)`
| `parseAndStripWhitespace(s)`
| `parseDocument(s)`
| `stripWhitespace(element, tab)`

Variable Summary
`str` | `base64RegEx` = `'[A-Za-z0-9+/]+={0,4}\\Z'`
`str` | `booleanRegEx` = `'(true)|(false)'`
`str` | `certsListRegEx` = `'(0)?(1)?(2)?(3)?(4)?(5)?(6)?(7)?(8)?(9...`
`str` | `cryptoIDRegEx` = `'([a-km-z3-9]{5}\\.){3}[a-km-z3-9]{5}\\Z...`
`str` | `dateTimeRegEx` = `'\\d\\d\\d\\d-\\d\\d-\\d\\dT\\d\\d:\\d\\...`
`str` | `exprRegEx` = `'[a-zA-Z0-9 ,()]{1,200}\\Z'`
`str` | `keyRegEx` = `'[A-Z]\\Z'`
`str` | `keysListRegEx` = `'(A)?(B)?(C)?(D)?(E)?(F)?(G)?(H)?(I)?(J)...`
`str` | `nsRegEx` = `'http://trevp.net/cryptoID\\Z'`
`str` | `sha1Base64RegEx` = `'[A-Za-z0-9+/]{27}=\\Z'`
`str` | `shortStringRegEx` = `'.{1,100}\\Z'`
`str` | `urlRegEx` = `'http(s)?://.{1,100}\\Z'`

Variable Details

    ### base64RegEx Type: `str` Value:
        '[A-Za-z0-9+/]+={0,4}\\Z'

    ### booleanRegEx Type: `str` Value:
        '(true)|(false)'

    ### certsListRegEx Type: `str` Value:
        '(0)?(1)?(2)?(3)?(4)?(5)?(6)?(7)?(8)?(9)?\\Z'

    ### cryptoIDRegEx Type: `str` Value:
        '([a-km-z3-9]{5}\\.){3}[a-km-z3-9]{5}\\Z'

    ### dateTimeRegEx Type: `str` Value:
        '\\d\\d\\d\\d-\\d\\d-\\d\\dT\\d\\d:\\d\\d:\\d\\dZ\\Z'

    ### exprRegEx Type: `str` Value:
        '[a-zA-Z0-9 ,()]{1,200}\\Z'

    ### keyRegEx Type: `str` Value:
        '[A-Z]\\Z'

    ### keysListRegEx Type: `str` Value:
        '(A)?(B)?(C)?(D)?(E)?(F)?(G)?(H)?(I)?(J)?(K)?(L)?(M)?(N)?(O)?(P)?(Q)?(\
        R)?(S)?(T)?(U)?(V)?(W)?(X)?(Y)?(Z)?\\Z'

    ### nsRegEx Type: `str` Value:
        'http://trevp.net/cryptoID\\Z'

    ### sha1Base64RegEx Type: `str` Value:
        '[A-Za-z0-9+/]{27}=\\Z'

    ### shortStringRegEx Type: `str` Value:
        '.{1,100}\\Z'

    ### urlRegEx Type: `str` Value:
        'http(s)?://.{1,100}\\Z'

Generated by Epydoc 2.0 on Mon Feb 21 21:56:53 2005 | http://epydoc.sf.net